@@ -26,15 +26,20 @@
 
 """Synchronous client API for PyCOM nameserver."""
 
+import threading
+
 from . import base, constants, exceptions, interfaces, protocol
 
 
 def nameserver():
-    """Get nameserver component."""
-    global _nameserver
+    """Get nameserver component.
 
-    if _nameserver is not None:
-        return _nameserver
+    While this functions is *thread-safe*, resulting object is NOT!
+
+    """
+    ns_component = getattr(_tls, "ns_component", None)
+    if ns_component is not None:
+        return ns_component
 
     ns_conf = base.configuration.get("nameserver", constants.NS_NAME_LOCAL)
     if ns_conf == constants.NS_NAME_LOCAL:
@@ -44,13 +49,14 @@ def nameserver():
             ns_instance = None
 
         if ns_instance is not None:
-            _nameserver = ns_instance.__interface__
+            ns_component = ns_instance.__interface__
         else:
             raise exceptions.ServiceNotFound("Nameserver not found")
     else:
-        _nameserver = protocol.detect_ns(ns_conf)
+        ns_component = protocol.detect_ns(ns_conf)
 
-    return _nameserver
+    _tls.ns_component = ns_component
+    return ns_component
 
 
 def locate(iface, service_name=None):
@@ -59,6 +65,8 @@ def locate(iface, service_name=None):
     If *service_name* is specified,
     only service with this name will be returned.
 
+    While this functions is *thread-safe*, resulting object is NOT!
+
     """
     ns_component = nameserver()
     try:
@@ -76,4 +84,4 @@ def locate(iface, service_name=None):
 
 # Private
 
-_nameserver = None
+_tls = threading.local()
