@@ -26,10 +26,14 @@
 
 """Tests for pycom.launcher."""
 
+import io
 import random
+import sys
 import threading
 import time
 
+from six import StringIO
+
 import pycom
 import pycom.apps.nameserver
 from pycom import base, constants, nsclient, protocol, utils
@@ -44,7 +48,9 @@ class MainTest(BaseTest, unittest.TestCase):
         super(MainTest, self).setUp()
         self.oldConf = base.configuration.copy()
         base.configuration.clear()
-        nsclient._nameserver = pycom.apps.nameserver.NameServer().__interface__
+
+        nsclient._tls.ns_component = \
+            pycom.apps.nameserver.NameServer().__interface__
 
     def tearDown(self):
         base.configuration.clear()
@@ -179,3 +185,45 @@ def _testSession(request):
         request.session["test"] = request.args
 
     return request.session["test"]
+
+
+class ArgsTest(unittest.TestCase):
+
+    def setUp(self):
+        super(ArgsTest, self).setUp()
+        self.oldConf = base.configuration.copy()
+        base.configuration.clear()
+
+    def tearDown(self):
+        base.configuration.clear()
+        base.configuration.update(self.oldConf)
+        super(ArgsTest, self).tearDown()
+
+    def testFailEmptyArgs(self):
+        with Replacer(sys, "stderr", StringIO()):
+            self.assertRaises(SystemExit, pycom.main, [])
+
+    def testFailEmptyAddress(self):
+        with Replacer(sys, "stderr", StringIO()):
+            self.assertRaises(SystemExit, pycom.main, ["sys", "-a"])
+
+    def testFailEmptyService(self):
+        with Replacer(sys, "stderr", StringIO()):
+            self.assertRaises(SystemExit, pycom.main, ["sys", "-s"])
+
+    def testFailUnknownOption(self):
+        with Replacer(sys, "stderr", StringIO()):
+            self.assertRaises(SystemExit, pycom.main, ["sys", "-x"])
+
+    def testCorrectOptions(self):
+        address = "ipc://pycom/test_launcher-%d" % random.randint(0, 999999)
+
+        pycom.ioloop().add_callback(pycom.ioloop().stop)
+        pycom.main(["sys", "-a", address, "-s", "/test/test_launcher2"])
+
+    def testUnknownModule(self):
+        address = "ipc://pycom/test_launcher-%d" % random.randint(0, 999999)
+
+        with Replacer(sys, "stderr", StringIO()):
+            self.assertRaises(SystemExit, pycom.main,
+                ["banana!", "-a", address, "-s", "/test/test_launcher2"])
