@@ -41,12 +41,12 @@ class BaseTest(InterfacesBaseTest):
 
     def setUp(self):
         super(BaseTest, self).setUp()
-        self.oldNS = nsclient._nameserver
-        nsclient._nameserver = None
+        self.oldNS = getattr(nsclient._tls, "ns_component", None)
+        nsclient._tls.ns_component = None
         pycom.configure(nameserver="local")
 
     def tearDown(self):
-        nsclient._nameserver = self.oldNS
+        nsclient._tls.ns_component = self.oldNS
         super(BaseTest, self).tearDown()
 
 class LocalNSTest(BaseTest, unittest.TestCase):
@@ -112,12 +112,10 @@ def ns_handler(request):
         return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
 
 
-class RemoteNSTest(unittest.TestCase):
+class RemoteNSTest(BaseTest, unittest.TestCase):
 
     def setUp(self):
         super(RemoteNSTest, self).setUp()
-        self.oldNS = nsclient._nameserver
-        nsclient._nameserver = None
 
         addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
         pycom.configure(nameserver=addr)
@@ -136,7 +134,7 @@ class RemoteNSTest(unittest.TestCase):
         del self.event
         self.thread.join()
         del self.thread
-        nsclient._nameserver = self.oldNS
+
         super(RemoteNSTest, self).tearDown()
 
     def testNS(self):
@@ -173,12 +171,10 @@ def ns_handler_w_error(request):
         return 100500, None, None, None
 
 
-class LocateFailureTest(unittest.TestCase):
+class LocateFailureTest(BaseTest, unittest.TestCase):
 
     def setUp(self):
         super(LocateFailureTest, self).setUp()
-        self.oldNS = nsclient._nameserver
-        nsclient._nameserver = None
 
         addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
         pycom.configure(nameserver=addr)
@@ -197,7 +193,7 @@ class LocateFailureTest(unittest.TestCase):
         del self.event
         self.thread.join()
         del self.thread
-        nsclient._nameserver = self.oldNS
+
         super(LocateFailureTest, self).tearDown()
 
     def testUnknownError(self):
@@ -224,12 +220,10 @@ def ns_handler2(request):
             return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
 
 
-class LocateTest(unittest.TestCase):
+class LocateTest(BaseTest, unittest.TestCase):
 
     def setUp(self):
         super(LocateTest, self).setUp()
-        self.oldNS = nsclient._nameserver
-        nsclient._nameserver = None
 
         addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
         pycom.configure(nameserver=addr)
@@ -248,7 +242,7 @@ class LocateTest(unittest.TestCase):
         del self.event
         self.thread.join()
         del self.thread
-        nsclient._nameserver = self.oldNS
+
         super(LocateTest, self).tearDown()
 
     def testLocate(self):
